UpdateStatus enum

The current status of the app in terms of whether its up-to-date.

Inheritance
Available extensions

Values

upToDate → const UpdateStatus

The app is up to date (e.g. running the latest patch.)

outdated → const UpdateStatus

A new update is available for download.

restartRequired → const UpdateStatus

The app is up to date, but a restart is required for the update to take effect.

unavailable → const UpdateStatus

The update status is unavailable. This occurs when the updater is not available in the current build. See also:

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UpdateStatus>
A constant List of the values in this enum, in order of their declaration.